package com.zhyc.module.feed.service;

import java.util.List;
import com.zhyc.module.feed.domain.SgFormulaList;

/**
 * 配方列表Service接口
 * 
 * @author HashMap
 * @date 2025-08-09
 */
public interface ISgFormulaListService 
{
    /**
     * 查询配方列表
     * 
     * @param code 配方列表主键
     * @return 配方列表
     */
    SgFormulaList selectSgFormulaListByCode(Long code);

    /**
     * 查询配方列表列表
     * 
     * @param sgFormulaList 配方列表
     * @return 配方列表集合
     */
    List<SgFormulaList> selectSgFormulaListList(SgFormulaList sgFormulaList);

    /**
     * 新增配方列表
     * 
     * @param sgFormulaList 配方列表
     * @return 结果
     */
    int insertSgFormulaList(SgFormulaList sgFormulaList);

    /**
     * 修改配方列表
     * 
     * @param sgFormulaList 配方列表
     * @return 结果
     */
    int updateSgFormulaList(SgFormulaList sgFormulaList);

    /**
     * 批量删除配方列表
     * 
     * @param codes 需要删除的配方列表主键集合
     * @return 结果
     */
    int deleteSgFormulaListByCodes(Long[] codes);

    /**
     * 删除配方列表信息
     * 
     * @param code 配方列表主键
     * @return 结果
     */
    int deleteSgFormulaListByCode(Long code);

    int deleteSgFormulaListByFormulaIdAndBatchId(SgFormulaList sgFormulaList);
}
